//-----------------------------------------------------------------------------
// Weapon_SFKatana
// SolarFlare
//-----------------------------------------------------------------------------

if(!isObject(swordDrawSound))
{
   datablock AudioProfile(swordDrawSound)
   {
      filename    = "Weapon_Sword/swordDraw.wav";
      description = AudioClosest3d;
      preload = true;
   };
   datablock AudioProfile(swordHitSound)
   {
      filename    = "Weapon_Sword/swordHit.wav";
      description = AudioClosest3d;
      preload = true;
   };
}

datablock AudioProfile(katanaDashSound)
{
   filename    = "./katanaDashSound.wav";
   description = AudioClosest3d;
   preload = true;
};

//-----------------------------------------------------------------------------
// Effects

datablock ParticleData(katanaExplosionParticle)
{
   dragCoefficient      = 2;
   gravityCoefficient   = 1.0;
   inheritedVelFactor   = 0.2;
   constantAcceleration = 0.0;
   spinRandomMin = -90;
   spinRandomMax = 90;
   lifetimeMS           = 500;
   lifetimeVarianceMS   = 300;
   textureName          = "base/data/particles/chunk";
   colors[0]     = "0.7 0.7 0.9 0.9";
   colors[1]     = "0.9 0.9 0.9 0.0";
   sizes[0]      = 0.5;
   sizes[1]      = 0.25;
};

datablock ParticleEmitterData(katanaExplosionEmitter)
{
   ejectionPeriodMS = 7;
   periodVarianceMS = 0;
   ejectionVelocity = 8;
   velocityVariance = 1.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 60;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "katanaExplosionParticle";

   uiName = "Katana Hit";
};

datablock ExplosionData(katanaExplosion)
{
   lifeTimeMS = 500;

   soundProfile = swordHitSound;

   particleEmitter = katanaExplosionEmitter;
   particleDensity = 10;
   particleRadius = 0.2;

   faceViewer     = true;
   explosionScale = "1 1 1";

   shakeCamera = true;
   camShakeFreq = "20.0 22.0 20.0";
   camShakeAmp = "1.0 1.0 1.0";
   camShakeDuration = 0.5;
   camShakeRadius = 10.0;

   lightStartRadius = 3;
   lightEndRadius = 0;
   lightStartColor = "0.6 0.2 0.0";
   lightEndColor = "0 0 0";
};

datablock ParticleData(dashPuffParticle)
{
   dragCoefficient      = 3;
   gravityCoefficient   = -0.0;
   inheritedVelFactor   = 0.0;
   constantAcceleration = 0.0;
   lifetimeMS           = 200;
   lifetimeVarianceMS   = 50;
   textureName          = "base/data/particles/cloud";
   spinSpeed		= 10.0;
   spinRandomMin		= -500.0;
   spinRandomMax		= 500.0;
   colors[0]     = "0.8 0.8 0.8 0.3";
   colors[1]     = "0.8 0.8 0.8 0.3";
   sizes[0]      = 0.5;
   sizes[1]      = 0.6;

   useInvAlpha = true;
};
datablock ParticleEmitterData(dashPuffEmitter)
{
   ejectionPeriodMS = 7;
   periodVarianceMS = 0;
   ejectionVelocity = 0.0;
   velocityVariance = 0.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 90;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvance = false;
   particles = "dashPuffParticle";
};

//-----------------------------------------------------------------------------
// Projectile

AddDamageType("Katana", '<bitmap:add-ons/Weapon_SFKatana/CI_katana> %1', '%2 <bitmap:add-ons/Weapon_SFKatana/CI_katana> %1', 0.75, 1);

datablock ProjectileData(katanaProjectile)
{
   directDamage        = 60;
   directDamageType    = $DamageType::katana;
   radiusDamageType    = $DamageType::katana;
   explosion           = katanaExplosion;

   muzzleVelocity      = 50;
   velInheritFactor    = 1;

   armingDelay         = 0;
   lifetime            = 100;
   fadeDelay           = 70;
   bounceElasticity    = 0;
   bounceFriction      = 0;
   isBallistic         = false;
   gravityMod          = 0.0;

   hasLight            = false;
   lightRadius         = 3.0;
   lightColor          = "0 0 0.5";

   uiName              = "Katana Slice";
};

//-----------------------------------------------------------------------------
// Item

datablock ItemData(katanaItem)
{
   category = "Weapon";
   className = "Weapon";

   shapeFile = "./katana.dts";
   mass = 1;
   density = 0.2;
   elasticity = 0.2;
   friction = 0.6;
   emap = true;

   uiName = "Katana";
   iconName = "./icon_Katana";
   doColorShift = false;

   image = katanaImage;
   canDrop = true;
};

//-----------------------------------------------------------------------------
// Weapon Image

datablock ShapeBaseImageData(katanaImage)
{
   shapeFile = "./katana.dts";
   emap = true;

   mountPoint = 0;
   offset = "0 0 0";

   correctMuzzleVector = false;

   className = "WeaponImage";

   item = katanaItem;
   ammo = "";
   projectile = katanaProjectile;
   projectileType = Projectile;

   melee = true;
   doRetraction = false;
   armReady = true;

   doColorShift = false;

   stateName[0]                     = "Activate";
   stateTimeoutValue[0]             = 0.5;
   stateTransitionOnTimeout[0]      = "Ready";
   stateSound[0]                    = swordDrawSound;

   stateName[1]                     = "Ready";
   stateTransitionOnTriggerDown[1]  = "PreFire";
   stateAllowImageChange[1]         = true;

   stateName[2]			    = "PreFire";
   stateScript[2]                   = "onPreFire";
   stateAllowImageChange[2]         = false;
   stateTimeoutValue[2]             = 0.1;
   stateTransitionOnTimeout[2]      = "Fire";

   stateName[3]                     = "Fire";
   stateTransitionOnTimeout[3]      = "CheckFire";
   stateTimeoutValue[3]             = 0.2;
   stateFire[3]                     = true;
   stateAllowImageChange[3]         = false;
   stateSequence[3]                 = "Fire";
   stateScript[3]                   = "onFire";
   stateWaitForTimeout[3]	    = true;

   stateName[4]			    = "CheckFire";
   stateTransitionOnTriggerUp[4]    = "StopFire";
   stateTransitionOnTriggerDown[4]  = "Fire";

   stateName[5]                     = "StopFire";
   stateTransitionOnTimeout[5]      = "Ready";
   stateTimeoutValue[5]             = 0.2;
   stateAllowImageChange[5]         = false;
   stateWaitForTimeout[5]	    = true;
   stateSequence[5]                 = "StopFire";
   stateScript[5]                   = "onStopFire";
};

//-----------------------------------------------------------------------------
// Script

function katanaImage::onPreFire(%this, %obj, %slot)
{
   %obj.playThread(2, armAttack);
}

function katanaImage::onStopFire(%this, %obj, %slot)
{	
   %obj.playThread(2, root);
}

//-----------------------------------------------------------------------------
// Secondary Fire

package katanaDash
{
   function armor::onTrigger(%this,%player,%slot,%val)
   {
      if(%player.getMountedImage(0) $= katanaImage.getID() && %slot $= 4)
      {
         if(%val)
         {
            %curVelocity = %player.getVelocity();
            %velX = getWord(%curVelocity, 0);
            %velY = getWord(%curVelocity, 1);
            %velZ = getWord(%curVelocity, 2);
            if(%velX < 8 && %velX > -8 && %velY < 8 && %velY > -8)
            {
               %finalVel = vectorScale(%velX SPC %velY SPC %velZ, 3.2);
               %player.setVelocity(getWords(%finalVel, 0, 1) SPC %velZ + 1);
               %player.playAudio(0, katanaDashSound);
               %node = new ParticleEmitterNode()
               {
                  position = %player.getPosition();
                  dataBlock = GenericEmitterNode;
                  emitter = dashPuffEmitter;
               };
               %node.schedule(100, delete);
            }
            else
               parent::onTrigger(%this, %player, %slot, %val);
         }
         else
            parent::onTrigger(%this, %player, %slot, %val);
      }
      else
         parent::onTrigger(%this, %player, %slot, %val);
   }
};
activatePackage(katanaDash);